==> haskell-libyaml-0.1.4-117-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-libyaml.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                   libyaml
version:                0.1.4
visibility:             public
id:                     libyaml-0.1.4-UfvM8Sc9Hr8VHboy3uTms
key:                    libyaml-0.1.4-UfvM8Sc9Hr8VHboy3uTms
license:                BSD-3-Clause
maintainer:             Michael Snoyman <michael@snoyman.com>
author:
    Michael Snoyman <michael@snoyman.com>, Anton Ageev <antage@gmail.com>,Kirill Simonov

stability:              stable
homepage:               https://github.com/snoyberg/yaml#readme
synopsis:               Low-level, streaming YAML interface.
description:
    README and API documentation are available at <https://www.stackage.org/package/libyaml>

category:               Text
abi:                    eaf178ee61c4caa647cc3821c073189c
exposed:                True
exposed-modules:        Text.Libyaml
hidden-modules:         Paths_libyaml
import-dirs:            /usr/lib/ghc-9.4.8/site-local/libyaml-0.1.4
library-dirs:           /usr/lib/ghc-9.4.8/site-local/libyaml-0.1.4
library-dirs-static:    /usr/lib/ghc-9.4.8/site-local/libyaml-0.1.4
dynamic-library-dirs:   /usr/lib
data-dir:               /usr/share/haskell-libyaml
hs-libraries:           HSlibyaml-0.1.4-UfvM8Sc9Hr8VHboy3uTms
extra-libraries:        yaml
extra-libraries-static: yaml
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    conduit-1.3.6.1-6jCM8OP1Acj1IIa26Jdl9d
    resourcet-1.2.6-3ZqxfisK1jQJQLApAB05ya

haddock-interfaces:     /usr/share/doc/haskell-libyaml/html/libyaml.haddock
haddock-html:           /usr/share/doc/haskell-libyaml/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-libyaml-0.1.4-118-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-libyaml.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                   libyaml
version:                0.1.4
visibility:             public
id:                     libyaml-0.1.4-1uJMP32okYMF6xn22WE0Mx
key:                    libyaml-0.1.4-1uJMP32okYMF6xn22WE0Mx
license:                BSD-3-Clause
maintainer:             Michael Snoyman <michael@snoyman.com>
author:
    Michael Snoyman <michael@snoyman.com>, Anton Ageev <antage@gmail.com>,Kirill Simonov

stability:              stable
homepage:               https://github.com/snoyberg/yaml#readme
synopsis:               Low-level, streaming YAML interface.
description:
    README and API documentation are available at <https://www.stackage.org/package/libyaml>

category:               Text
abi:                    c18356a0c3160092953fe0dc3b0ed5b3
exposed:                True
exposed-modules:        Text.Libyaml
hidden-modules:         Paths_libyaml
import-dirs:            /usr/lib/ghc-9.4.8/site-local/libyaml-0.1.4
library-dirs:           /usr/lib/ghc-9.4.8/site-local/libyaml-0.1.4
library-dirs-static:    /usr/lib/ghc-9.4.8/site-local/libyaml-0.1.4
dynamic-library-dirs:   /usr/lib
data-dir:               /usr/share/haskell-libyaml
hs-libraries:           HSlibyaml-0.1.4-1uJMP32okYMF6xn22WE0Mx
extra-libraries:        yaml
extra-libraries-static: yaml
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    conduit-1.3.6.1-83ARrK7GmQf2qu3DMBdhJp
    resourcet-1.2.6-6OalXqf73l86eTJ5NzIFB9

haddock-interfaces:     /usr/share/doc/haskell-libyaml/html/libyaml.haddock
haddock-html:           /usr/share/doc/haskell-libyaml/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
